@@ -3,7 +3,7 @@ package App::Greple::stripe;
 use 5.024;
 use warnings;
 
-our $VERSION = "0.9902";
+our $VERSION = "0.9903";
 
 =encoding utf-8
 
@@ -17,7 +17,7 @@ App::Greple::stripe - Greple zebra stripe module
 
 =head1 VERSION
 
-Version 0.9902
+Version 0.9903
 
 =head1 DESCRIPTION
 
@@ -63,8 +63,9 @@ C<--need=1> option is required to relax this condition.
 <img width="750" src="https://raw.githubusercontent.com/kaz-utashiro/greple-stiripe/refs/heads/main/images/random.png">
 </p>
 
-If you want to use three series with three patterns, specify C<step>
-when calling the module.
+If you want to use different color series for three or more patterns,
+specify C<step> count when calling the module.  The number of series
+can be increased up to 6.
 
     greple -Mstripe::set=step=3 --need=1 -E p1 -E p2 -E p3 ...
 
@@ -160,7 +161,7 @@ sub hash_to_spec {
 my %series = (
     light => [
 	[ qw(/544 /533) ],
-	[ qw(/454 /353) ],
+	[ qw(/454 /252) ],
 	[ qw(/445 /335) ],
 	[ qw(/554 /553) ],
 	[ qw(/545 /535) ],
@@ -200,7 +201,7 @@ sub finalize {
     our($mod, $my_argv, $argv) = mod_argv @_;
     getopt $my_argv, \%opt;
     my @default = qw(--stripe-postgrep);
-    my @cm;
+    my @cm = qw(@);
     my $map = $opt{darkmode} ? $series{dark} : $series{light};
     for my $i (0, 1) {
 	for my $s (0 .. $opt{step} - 1) {
@@ -208,7 +209,7 @@ sub finalize {
 	}
     }
     local $" = ',';
-    $mod->setopt(default => join(' ', @default, '--cm=@', "--cm=@cm"));
+    $mod->setopt(default => join(' ', @default, "--cm=@cm"));
 }
 
 #
